import os
import numpy as np
import torch
from torch.utils.data import Dataset
import opts
from opts import *


torch.manual_seed(randomseed); torch.cuda.manual_seed_all(randomseed); np.random.seed(randomseed)
torch.backends.cudnn.deterministic - True

class VideoDataset(Dataset):

    def __init__(self, mode, datasetName = 'SYSU_SyncDiving'):
        super(VideoDataset, self).__init__()
        self.mode = mode
        self.annot_data = np.load(opts._data_path).item()
        self.datasetName = datasetName
        self.AQA_7 = ['diving', 'gym_vault', 'ski_big_air', 'snowboard_big_air', 'sync_diving_3m', 'sync_diving_10m','figure_skating']
        if datasetName in self.AQA_7:
            self.annot_data_joints = np.load(opts._data_path2).item()
    def __getitem__(self, ix):
        data = {}
        data['whole_i3d'] = torch.tensor(np.array(self.annot_data[self.mode]['whole'])[ix]).float().squeeze()
        if self.datasetName == 'sysu_sync_diving_3m' or self.datasetName == 'sysu_sync_diving_10m':
            data['master'] = torch.tensor(np.array(self.annot_data[self.mode]['joints_left'])[ix]).float().squeeze()
            data['slave'] = torch.tensor(np.array(self.annot_data[self.mode]['joints_right'])[ix]).float().squeeze()
            #print(data['joints'].shape)
            data['true_final_score'] = torch.tensor(np.array(self.annot_data[self.mode]['std_score'])[ix]).float()
            data['true_exec_score'] = torch.tensor(np.array(self.annot_data[self.mode]['exec_score_diff'])[ix]).float()
            data['true_sync_score'] = torch.tensor(np.array(self.annot_data[self.mode]['sync_score'])[ix]).float()
        elif self.datasetName in self.AQA_7:
            data['master'] = torch.tensor(np.array(self.annot_data_joints[self.mode]['joints'])[ix]).float().squeeze()
            data['slave'] = torch.tensor(np.array(self.annot_data_joints[self.mode]['flow'])[ix]).float().squeeze()
            data['score'] = torch.tensor(np.array(self.annot_data[self.mode]['score'][ix])).float()
        else:
            data['master'] = torch.tensor(np.array(self.annot_data[self.mode]['patch'][ix][0:2])).float().squeeze()
            #print(data['patch'].shape)
            data['master'] = torch.tensor(data['master'].permute(1, 0, 2)).view([opts._SEG, -1])
            data['slave'] = torch.tensor(np.array(self.annot_data[self.mode]['patch'][ix][2:4])).float().squeeze()
            #print(data['patch'].shape)
            data['slave'] = torch.tensor(data['slave'].permute(1, 0, 2)).view([opts._SEG, -1])

            #print(data['patch'].shape)
            data['score'] = torch.tensor(np.array(self.annot_data[self.mode]['score'][ix])).float()


        return data

    def __len__(self):
        #print('Data len:', len(np.array(self.annot_data[self.mode]['whole'])))
        return len(np.array(self.annot_data[self.mode]['whole']))
